Learn R Programming

CINdex (version 1.0.2)

clin.crc: Colon cancer clinical dataset

Description

The example dataset consisits of 10 colon cancer patients, of which 5 had relapse (return of cancer to colon) and the rest did not relapse. This example dataset is part of the complete dataset used in CRC, and can be accessed via G-DOC Plus at https://gdoc.georgetown.edu. The column names are described below:

Usage

data(clin.crc)

Arguments

Value

Format

A matrix with 10 rows and 2 columns

Details

  • Sample. Sample ID
  • Label. Refers to the group label/outcome

More details on how this object was created is provided in the vignette titled "How to prepare Input data" in the CINdex package.