A CDS gene annotation file with the following column names (obtained for human reference)
- chrom. Chromosome number
- strand. Positive or negative strand
- cdsStart. CDS Start position
- cdsEnd. CDS end position
- GeneID. Gene symbol
More details on how this object was created is provided in the vignette titled "How to prepare Input data" in the CINdex package.